@@ -45,12 +45,13 @@ class PasswordMixin(forms.SelfHandlingForm):
         error_messages={'invalid': validators.password_validator_msg()})
     confirm_password = forms.CharField(
         label=_("Confirm Password"),
+        strip=False,
         widget=forms.PasswordInput(render_value=False))
     no_autocomplete = True
 
     def clean(self):
         '''Check to make sure password fields match.'''
-        data = super(PasswordMixin, self).clean()
+        data = super().clean()
         if 'password' in data and 'confirm_password' in data:
             if data['password'] != data['confirm_password']:
                 raise ValidationError(_('Passwords do not match.'))
@@ -59,7 +60,7 @@ class PasswordMixin(forms.SelfHandlingForm):
 
 class BaseUserForm(forms.SelfHandlingForm):
     def __init__(self, request, *args, **kwargs):
-        super(BaseUserForm, self).__init__(request, *args, **kwargs)
+        super().__init__(request, *args, **kwargs)
 
         # Populate project choices
         project_choices = []
@@ -133,7 +134,7 @@ class CreateUserForm(PasswordMixin, BaseUserForm, AddExtraColumnMixIn):
 
     def __init__(self, *args, **kwargs):
         roles = kwargs.pop('roles')
-        super(CreateUserForm, self).__init__(*args, **kwargs)
+        super().__init__(*args, **kwargs)
         # Reorder form fields from multiple inheritance
         ordering = ["domain_id", "domain_name", "name",
                     "description", "email", "password",
@@ -234,7 +235,7 @@ class UpdateUserForm(BaseUserForm, AddExtraColumnMixIn):
                                        initial=False)
 
     def __init__(self, request, *args, **kwargs):
-        super(UpdateUserForm, self).__init__(request, *args, **kwargs)
+        super().__init__(request, *args, **kwargs)
         self.add_extra_fields()
         if api.keystone.keystone_can_edit_user() is False:
             for field in ('name', 'email'):
@@ -275,8 +276,8 @@ class UpdateUserForm(BaseUserForm, AddExtraColumnMixIn):
 
         if isinstance(response, http.HttpResponse):
             return response
-        else:
-            return True
+
+        return True
 
 
 class ChangePasswordForm(PasswordMixin, forms.SelfHandlingForm):
@@ -287,11 +288,12 @@ class ChangePasswordForm(PasswordMixin, forms.SelfHandlingForm):
         required=False)
 
     def __init__(self, request, *args, **kwargs):
-        super(ChangePasswordForm, self).__init__(request, *args, **kwargs)
+        super().__init__(request, *args, **kwargs)
 
         if settings.ENFORCE_PASSWORD_CHECK:
             self.fields["admin_password"] = forms.CharField(
                 label=_("Admin Password"),
+                strip=False,
                 widget=forms.PasswordInput(render_value=False))
             # Reorder form fields from multiple inheritance
             self.fields.keyOrder = ["id", "name", "admin_password",
@@ -339,5 +341,5 @@ class ChangePasswordForm(PasswordMixin, forms.SelfHandlingForm):
 
         if isinstance(response, http.HttpResponse):
             return response
-        else:
-            return True
+
+        return True
