@@ -22,14 +22,15 @@ var path = require('path');
 module.exports = function (config) {
   var xstaticPath = path.resolve('./.tox/npm');
 
-  if (fs.existsSync(xstaticPath)) {
-    xstaticPath += '/lib/python2.7/site-packages/xstatic/pkg/';
-  }
-
   if (!xstaticPath) {
     console.error('xStatic libraries not found, please run `tox -e npm`');
     process.exit(1);
   }
+  xstaticPath += '/lib/';
+  xstaticPath += fs.readdirSync(xstaticPath).find(function(directory) {
+    return directory.indexOf('python') === 0;
+  });
+  xstaticPath += '/site-packages/xstatic/pkg/';
 
   config.set({
     preprocessors: {
@@ -89,8 +90,6 @@ module.exports = function (config) {
       xstaticPath + 'rickshaw/data/rickshaw.js',
       xstaticPath + 'angular_smart_table/data/smart-table.js',
       xstaticPath + 'angular_lrdragndrop/data/lrdragndrop.js',
-      xstaticPath + 'spin/data/spin.js',
-      xstaticPath + 'spin/data/spin.jquery.js',
       xstaticPath + 'tv4/data/tv4.js',
       xstaticPath + 'objectpath/data/ObjectPath.js',
       xstaticPath + 'angular_schema_form/data/schema-form.js',
@@ -161,14 +160,14 @@ module.exports = function (config) {
 
     frameworks: ['jasmine'],
 
-    browsers: ['Chrome'],
+    browsers: ['Firefox'],
 
     browserNoActivityTimeout: 60000,
 
     reporters: ['progress', 'coverage', 'threshold'],
 
     plugins: [
-      'karma-chrome-launcher',
+      'karma-firefox-launcher',
       'karma-jasmine',
       'karma-ng-html2js-preprocessor',
       'karma-coverage',
@@ -181,6 +180,12 @@ module.exports = function (config) {
       dir: '../cover/openstack_dashboard'
     },
 
+    client: {
+      jasmine: {
+        random: false
+      }
+    },
+
     // Coverage threshold values.
     thresholdReporter: {
       statements: 96, // target 100
